Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(437)

Unified Diff: pkg/analyzer/lib/src/generated/engine.dart

Issue 2392983002: Deprecate analysis option "cacheSize". (Closed)
Patch Set: Created 4 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « pkg/analysis_server/lib/src/status/get_handler.dart ('k') | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: pkg/analyzer/lib/src/generated/engine.dart
diff --git a/pkg/analyzer/lib/src/generated/engine.dart b/pkg/analyzer/lib/src/generated/engine.dart
index 1be94d60629d9fe46d0452fd69836b7c29840b1b..74f7d3db38896307b6efc329ddd4f3cd7afc749a 100644
--- a/pkg/analyzer/lib/src/generated/engine.dart
+++ b/pkg/analyzer/lib/src/generated/engine.dart
@@ -1061,9 +1061,12 @@ abstract class AnalysisOptions {
AnalyzeFunctionBodiesPredicate get analyzeFunctionBodiesPredicate;
/**
* Return the maximum number of sources for which AST structures should be
* kept in the cache.
+ *
+ * This setting no longer has any effect.
*/
+ @deprecated
int get cacheSize;
/**
@@ -1225,8 +1228,11 @@ abstract class AnalysisOptions {
*/
class AnalysisOptionsImpl implements AnalysisOptions {
/**
* The maximum number of sources for which data should be kept in the cache.
*/
+ @deprecated
static const int DEFAULT_CACHE_SIZE = 64;
static const int ENABLE_ASSERT_FLAG = 0x01;
@@ -1249,6 +1255,7 @@ class AnalysisOptionsImpl implements AnalysisOptions {
_analyzeAllFunctionBodies;
@override
+ @deprecated
int cacheSize = DEFAULT_CACHE_SIZE;
@override
« no previous file with comments | « pkg/analysis_server/lib/src/status/get_handler.dart ('k') | no next file » | no next file with comments »

Powered by Google App Engine
@@ -1061,9 +1061,12 @@ abstract class AnalysisOptions {
AnalyzeFunctionBodiesPredicate get analyzeFunctionBodiesPredicate;
/**
- * Return the maximum number of sources for which AST structures should be
+ * DEPRECATED: Return the maximum number of sources for which AST structures should be
* kept in the cache.
@@ -1225,8 +1228,11 @@ abstract class AnalysisOptions {
class AnalysisOptionsImpl implements AnalysisOptions {
/**
- * The maximum number of sources for which data should be kept in the cache.
+ * DEPRECATED: The maximum number of sources for which data should be kept in the cache.
+ *
+ * This constant no longer has any effect.
*/
This is Rietveld 408576698